@@ -27,6 +27,48 @@ for ref in ACTG:
 #%%
 
 
+def get_priors():
+
+    # # beta new
+    # A_prior = mu_phi_to_alpha_beta(mu=0.01, phi=1)  # mean = 0.01, concentration = 1
+    # q_prior = mu_phi_to_alpha_beta(mu=0.2, phi=5)  # mean = 0.2, concentration = 5
+    # c_prior = mu_phi_to_alpha_beta(mu=0.1, phi=10)  # mean = 0.01, concentration = 1
+
+    # beta old
+    # A_prior = mu_phi_to_alpha_beta(mu=0.2, phi=5)  # mean = 0.2, concentration = 5
+    # q_prior = mu_phi_to_alpha_beta(mu=0.2, phi=5)  # mean = 0.2, concentration = 5
+    # c_prior = mu_phi_to_alpha_beta(mu=0.1, phi=10)  # mean = 0.1, concentration = 10
+
+    A_prior = mu_phi_to_alpha_beta(mu=0.1, phi=10)  # mean = 0.1, concentration = 10
+    q_prior = mu_phi_to_alpha_beta(mu=0.2, phi=5)  # mean = 0.2, concentration = 5
+    c_prior = mu_phi_to_alpha_beta(mu=0.1, phi=10)  # mean = 0.1, concentration = 10
+
+    # exponential (min, scale)
+    phi_prior = (2, 1000)
+
+    return {
+        "A": A_prior,
+        "q": q_prior,
+        "c": c_prior,
+        "phi": phi_prior,
+    }
+
+
+def alpha_beta_to_mu_phi(alpha, beta):
+    mu = alpha / (alpha + beta)
+    phi = alpha + beta
+    return mu, phi
+
+
+def mu_phi_to_alpha_beta(mu, phi):
+    alpha = mu * phi
+    beta = phi * (1 - mu)
+    return alpha, beta
+
+
+#%%
+
+
 def downcast_dataframe(df, categories=None, fully_automatic=False):
 
     if categories is None:
@@ -39,8 +81,10 @@ def downcast_dataframe(df, categories=None, fully_automatic=False):
 
     int_cols = df2.select_dtypes(include=["integer"]).columns
 
+    int_type = "uint32"
     if df2[int_cols].max().max() > np.iinfo("uint32").max:
-        raise AssertionError("Dataframe contains too large values.")
+        int_type = "uint64"
+        # raise AssertionError("Dataframe contains too large values.")
 
     for col in int_cols:
         if fully_automatic:
@@ -49,7 +93,7 @@ def downcast_dataframe(df, categories=None, fully_automatic=False):
             if col == "position":
                 df2.loc[:, col] = df2[col].astype("int8")
             else:
-                df2.loc[:, col] = df2[col].astype("uint32")
+                df2.loc[:, col] = df2[col].astype(int_type)
 
     for col in df2.select_dtypes(include=["float"]).columns:
         if fully_automatic:
@@ -72,22 +116,7 @@ def get_forward(df):
     return df.query("direction == @s")
 
 
-def get_priors():
-
-    # beta
-    A_prior = mu_phi_to_alpha_beta(mu=0.2, phi=5)  # mean = 0.2, concentration = 5
-    q_prior = mu_phi_to_alpha_beta(mu=0.2, phi=5)  # mean = 0.2, concentration = 5
-    c_prior = mu_phi_to_alpha_beta(mu=0.1, phi=10)  # mean = 0.1, concentration = 10
-
-    # exponential (min, scale)
-    phi_prior = (2, 1000)
-
-    return {
-        "A": A_prior,
-        "q": q_prior,
-        "c": c_prior,
-        "phi": phi_prior,
-    }
+#%%
 
 
 #%%
@@ -119,18 +148,6 @@ def sample_from_param_grid(param_grid, random_state=None):
     return parameters
 
 
-def alpha_beta_to_mu_phi(alpha, beta):
-    mu = alpha / (alpha + beta)
-    phi = alpha + beta
-    return mu, phi
-
-
-def mu_phi_to_alpha_beta(mu, phi):
-    alpha = mu * phi
-    beta = phi * (1 - mu)
-    return alpha, beta
-
-
 #%%
 
 
